#[non_exhaustive]#[repr(u8)]pub enum WireType {
Varint = 0,
Fixed64 = 1,
LengthDelimited = 2,
StartGroup = 3,
EndGroup = 4,
Fixed32 = 5,
}Expand description
Protobuf wire types.
Only wire types 0–5 are currently defined by the protobuf specification;
values 6 and 7 are reserved for future use. This enum is
#[non_exhaustive] so that adding new wire types in a future crate
version is not a breaking change for downstream match arms.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations