NullableDeserializeSeed

Struct NullableDeserializeSeed 

pub struct NullableDeserializeSeed<S>(pub S);
Available on crate feature json only.
DeserializeSeed that detects JSON null and returns None instead of delegating to the inner seed. Used by generated oneof deserializers so that null means “this variant is not set”.

Tuple Fields

0: S