decode_string

Function decode_string 

pub fn decode_string(buf: &mut impl Buf) -> Result<String, DecodeError>
Decode a string value: read a varint length prefix, then that many bytes, and validate that the bytes are valid UTF-8.

Errors